@@ -229,6 +229,9 @@ def determine_if_sne_are_discoverable(
 
         discoverableList.append(discoveryDict)
 
+
+    maxVal = np.max(redshiftArray)
+
     if plot:
         hitList = []
         missList = []
@@ -252,7 +255,7 @@ def determine_if_sne_are_discoverable(
             pathToOutputPlotsFolder=pathToOutputPlotDirectory,
             dataRange=False,
             ylabel=False,
-            radius=1.1,
+            radius=maxVal,
             circumference=False,
             prependNum=False)
 
